TSUMUGI Viewer

Phenotypic metrics
i
Phenotype severity is not displayed when phenotype evaluation is binary (presence/absence).
Phenotypes similarity: 1 - 100
Phenotype severity: 1 - 100
Biological annotations
Genotype
All
Homo
Hetero
Hemi
Sex
All
Female
Male
Life stage
i
Early: -16w, Interval: 17-48w, Late: 49w-
All
Embryo
Early
Interval
Late
i
Recenter and fit the current network in view.
i
Arrange modules into a grid to avoid overlap and fit on screen.
No Gene Network found
Highlight
Markup
Human Disease
i
Human Disease annotations use IMPC Disease Models. Genes associated with human diseases are highlighted with a red border.

i
Search for phenotypes to highlight. Genes with matching phenotypes are highlighted with a blue border.

Centrality
i
'Normalized' options divide the centrality score by the number of phenotypes observed in KO mice
Scale: 0
Visualization
Layout
Node repulsion
Scale: 5
Size & Width
Font size: 20
Line width: 5

Similarity of accessory phenotypes

Severity of target phenotype

Export
i
GraphML can be used for visualization in other network analysis tools.